@@ -1,5 +1,8 @@
 package Acme::Playpen::Utilities;
-$Acme::Playpen::Utilities::VERSION = '0.02';
+$Acme::Playpen::Utilities::VERSION = '0.03';
+use strict;
+use warnings;
+
 # Nothing to see here, move along.
 
 # That means you too, Toby :-)
